<?php

// $Id: exerciseplan_form.page.inc,v 1.28 2010/08/26 07:01:01 icc Exp $

/**
 * The exercise plan's form page
 */
function exerciseplan_form_page() {
  drupal_add_js(drupal_get_path('module', 'exerciseplan') . '/js/mousewheel.js');
  drupal_add_js(drupal_get_path('module', 'exerciseplan') . '/js/jScrollPane-1.2.2.js');
  drupal_add_js(drupal_get_path('module', 'exerciseplan') . '/js/jquery.bltcheckbox.js');
  drupal_add_js(drupal_get_path('module', 'exerciseplan') . '/js/jquery.textOverflow.0.1.1.js');
  drupal_add_js(array('exerciseplan' => array('skipFirstStep' => variable_get('exerciseplan_skip_first_step', 0))), 'setting');
  drupal_add_js(drupal_get_path('module', 'exerciseplan') . '/js/exerciseplan.js');
  return drupal_get_form('exerciseplan_form');
}

/**
 * The exercise plan's multi-step form
 */
function exerciseplan_form(&$form_state) {
  // Select theme
  $form['#theme'] = 'exerciseplan_form';

  /* 2nd step, choose plan name and type */
  $form['plan_name'] = array(
    '#type' => 'textfield',
    '#maxlength' => 64,
  );
  $form['plan_type'] = array(
    '#type' => 'radios',
    '#options' => array(t('Workout plan - warm up plan'), t('Perodic plan - weekly schedule')),
  );

  /* 3rd step, perodic plan */
  $form['plan_objective'] = array(
    '#type' => 'textfield',
    '#title' => t('Objective'),
    '#maxlength' => 256,
    '#size' => 60.
  );
  // Week number
  $week = date('W');
  $form['plan_' . $week] = array(
    '#type' => 'textfield',
    '#default_value' => $week,
    '#maxlength' => 2,
    //'#size' => 2,
  ); // Add one week
  for ($i = 0; $i < 7; $i++)
    $form['plan_' . $week . '_' . $i . '_0'] = array(
      '#type' => 'textfield',
      '#maxlength' => 30,
      //'#size' => 12,
    );

  /* 5th step, create a detailed plan for a workout session */
  $form['exercise_plan_name'] = array(
    '#type' => 'textfield',
    '#title' => t('Topic'),
    '#maxlength' => 64,
    '#size' => 14,
  );
  $form['exercise_plan_date'] = array(
    '#type' => 'textfield',
    '#title' => t('Date'),
    '#maxlength' => 32,
    '#size' => 8,
  );
  $form['exercise_plan_objective'] = array(
    '#type' => 'textfield',
    '#title' => t('Objective'),
    '#maxlength' => 64,
    '#size' => 50,
  );
  $form['exercises'] = array(
    '#type' => 'hidden',
    '#value' => '',
  );
  $form['exercise_amount'] = array(
    '#type' => 'textarea',
    '#cols' => '20',
    '#rows' => '4',
  );
  $form['exercise_why'] = array(
    '#type' => 'textarea',
    '#cols' => '30',
    '#rows' => '4',
  );

  /* 6th step, exercise library */
  $vid = variable_get('exerciseplan_vocabulary', NULL);
  $all_terms = taxonomy_get_tree($vid);

  // Translate localized terms
  $options = variable_get('i18ntaxonomy_vocabulary', array($vid => 0));
  if ($options[$vid] == 1)
    $all_terms = i18ntaxonomy_localize_terms($all_terms);

  $terms = array();
  foreach ($all_terms as $term) {
    foreach ($term->parents as $parent) {
      if ($parent == 0) {
        $terms[$term->tid] = $term->name;
        $children = array();
        foreach ($all_terms as $term_child) {
          foreach ($term_child->parents as $parent_child) {
            if ($parent_child == $term->tid) {
              $children[$term_child->tid] = $term_child->name;
              $childrens_children = array();
              foreach ($all_terms as $term_child_child) {
                foreach ($term_child_child->parents as $parent_child_child) {
                  if ($parent_child_child == $term_child->tid) {
                    $childrens_children[$term_child_child->tid] = $term_child_child->name;
                  }
                }
              }
              if (count($childrens_children) > 0) {
                $childrens_children[0] = t('All');
                $form['terms_' . $term->tid . '_' . $term_child->tid] = array(
                  '#type' => 'select',
                  '#options' => $childrens_children,
                  '#default_value' => 0,
                  '#attributes' => array('class' => 'hidden'),
                );
              }
            }
          }
        }
        if (count($children) > 0) {
          $children[0] = t('All');
          $form['terms_' . $term->tid] = array(
            '#type' => 'select',
            '#options' => $children,
            '#default_value' => 0,
            '#attributes' => array('class' => 'hidden'),
          );
        }
      }
    }
  }
  $terms[0] = t('All');
  $form['terms'] = array(
    '#title' => t('Filter'),
    '#type' => 'select',
    '#options' => $terms,
    '#default_value' => 0,
  );


  if ($vocabulary) {
    $result = db_query('SELECT tid, name FROM term_data WHERE vid = %d', $vocabulary);
    $vocabulary = db_fetch_array(db_query('SELECT vid, name FROM vocabulary WHERE vid = %d', $vocabulary));
    $terms = array(0 => t('None'));
    while ($term = db_fetch_array($result))
      $terms[$term['tid']] = $term['name'];
    $form['vocabulary_' . $i] = array(
      '#type' => 'select',
      '#title' => $vocabulary['name'],
      '#default_value' => 0,
      '#options' => $terms,
    );
    $form['vocabulary_' . $i . '_id'] = array(
      '#type' => 'hidden',
      '#value' => $vocabulary['vid'],
    );
  }


  // Submit button (we need a submit button even if we're not going to use it)
  $form['submit'] = array(
    '#type' => 'submit',
  );

  // We need to know what type of plan to print
  $form['print'] = array(
    '#type' => 'hidden',
    '#value' => '',
  );
  return $form;
}

/**
 * The exercise plan's form submission handler
 */
function exerciseplan_form_submit($form, &$form_state) {
  include 'exerciseplan_print_rtf.inc';
  exerciseplan_print_rtf();
}